power_cogs.config.tune package — power_cogs 0.1.0 documentation

# power_cogs.config.tune package

## Submodules

## power_cogs.config.tune.tune_config module

class `power_cogs.config.tune.tune_config.` `TuneConfig`(metric: str = 'loss', mode: str = 'min', num_samples: int = 1, name: Union[str, NoneType] = '${trainer.name}', checkpoint_freq: int = 100, checkpoint_at_end: bool = True, additional_config: Dict[str, Any] = <factory>)

  Bases: `object`

  `checkpoint_at_end` = True
  `checkpoint_freq` = 100
  `metric` = 'loss'
  `mode` = 'min'
  `name` = '${trainer.name}'
  `num_samples` = 1

## Module contents